==> trivy-0.57.1-1-aarch64.pkg.tar.xz: usr/share/doc/trivy/ecosystem/ide.md <==
# IDE and developer tools Integrations

## VSCode (Official)
[Visual Studio Code](https://code.visualstudio.com/) is an open source versatile code editor and development environment.

👉 Get it at: <https://github.com/aquasecurity/trivy-vscode-extension>

## JetBrains (Official)
[JetBrains](https://jetbrains.com) makes IDEs such as Goland, Pycharm, IntelliJ, Webstorm, and more.

The Trivy plugin for JetBrains IDEs lets you use Trivy right from your development environment.

👉 Get it at: <https://plugins.jetbrains.com/plugin/18690-trivy-findings-explorer>

## Kubernetes Lens (Official)
[Kubernetes Lens](https://k8slens.dev/) is a management application for Kubernetes clusters.

Trivy has an extension for Kubernetes Lens that lets you scan Kubernetes workloads and view the results in the Lens UI.

👉 Get it at: <https://github.com/aquasecurity/trivy-operator-lens-extension>

## Vim (Community)
[Vim](https://www.vim.org/) is a terminal based text editor.

Vim plugin for Trivy to install and run Trivy.

👉 Get it at: <https://github.com/aquasecurity/vim-trivy>

## Docker Desktop (Community)
[Docker Desktop](https://www.docker.com/products/docker-desktop/) is an easy way to install [Docker]() container engine on your development machine, and manage it in a GUI .

Trivy Docker Desktop extension for scanning container images for vulnerabilities and generating SBOMs

👉 Get it at: <https://github.com/aquasecurity/trivy-docker-extension>

## Rancher Desktop (Community)
[Rancher Desktop](https://rancherdesktop.io/) is an easy way to use containers and Kubernetes on your development machine, and manage it in a GUI.

Trivy is natively integrated with Rancher, no installation is needed. More info in Rancher documentation: <https://docs.rancherdesktop.io/getting-started/features#scanning-images>

## LazyTrivy (Community)
A terminal native UI for Trivy

👉 Get it at: <https://github.com/owenrumney/lazytrivy>

## Trivy Vulnerability explorer (Community)

Web application that allows to load a Trivy report in json format and displays the vulnerabilities of a single target in an interactive data table

👉 Get it at: <https://github.com/dbsystel/trivy-vulnerability-explorer>

## Trivy pre-commit (Community)

A trivy pre-commit hook that runs a `trivy fs` in your git repo before commiting, preventing you from commiting secrets in the first place.

👉 Get it at: <https://github.com/mxab/pre-commit-trivy>

## AWS CDK

[The AWS Cloud Development Kit (AWS CDK)](https://aws.amazon.com/cdk/) is an open-source software development framework to define cloud infrastructure in code and provision it through AWS CloudFormation.

### image-scanner-with-trivy (Community)

A CDK Construct Library to scan an image with trivy in CDK codes.

👉 Get it at: <https://constructs.dev/packages/image-scanner-with-trivy>

==> trivy-0.59.0-1-aarch64.pkg.tar.xz: usr/share/doc/trivy/ecosystem/ide.md <==
# IDE and developer tools Integrations

## VSCode (Official)

[Visual Studio Code](https://code.visualstudio.com/) is an open source versatile code editor and development environment.

👉 Get it at: <https://github.com/aquasecurity/trivy-vscode-extension>

## JetBrains (Official)

[JetBrains](https://jetbrains.com) makes IDEs such as Goland, Pycharm, IntelliJ, Webstorm, and more.

The Trivy plugin for JetBrains IDEs lets you use Trivy right from your development environment.

👉 Get it at: <https://plugins.jetbrains.com/plugin/18690-trivy-findings-explorer>

## Kubernetes Lens (Official)

[Kubernetes Lens](https://k8slens.dev/) is a management application for Kubernetes clusters.

Trivy has an extension for Kubernetes Lens that lets you scan Kubernetes workloads and view the results in the Lens UI.

👉 Get it at: <https://github.com/aquasecurity/trivy-operator-lens-extension>

## Vim (Community)

[Vim](https://www.vim.org/) is a terminal based text editor.

Vim plugin for Trivy to install and run Trivy.

👉 Get it at: <https://github.com/aquasecurity/vim-trivy>

## Docker Desktop (Community)

[Docker Desktop](https://www.docker.com/products/docker-desktop/) is an easy way to install [Docker]() container engine on your development machine, and manage it in a GUI .

Trivy Docker Desktop extension for scanning container images for vulnerabilities and generating SBOMs

👉 Get it at: <https://github.com/aquasecurity/trivy-docker-extension>

## Rancher Desktop (Community)

[Rancher Desktop](https://rancherdesktop.io/) is an easy way to use containers and Kubernetes on your development machine, and manage it in a GUI.

Trivy is natively integrated with Rancher, no installation is needed. More info in Rancher documentation: <https://docs.rancherdesktop.io/ui/images/#scanning-images>

## LazyTrivy (Community)

A terminal native UI for Trivy

👉 Get it at: <https://github.com/owenrumney/lazytrivy>

## Trivy Vulnerability explorer (Community)

Web application that allows to load a Trivy report in json format and displays the vulnerabilities of a single target in an interactive data table

👉 Get it at: <https://github.com/dbsystel/trivy-vulnerability-explorer>

## Trivy pre-commit (Community)

A trivy pre-commit hook that runs a `trivy fs` in your git repo before commiting, preventing you from commiting secrets in the first place.

👉 Get it at: <https://github.com/mxab/pre-commit-trivy>

## AWS CDK

[The AWS Cloud Development Kit (AWS CDK)](https://aws.amazon.com/cdk/) is an open-source software development framework to define cloud infrastructure in code and provision it through AWS CloudFormation.

### image-scanner-with-trivy (Community)

A CDK Construct Library to scan an image with trivy in CDK codes.

👉 Get it at: <https://constructs.dev/packages/image-scanner-with-trivy>

## Headlamp plugin (Community)

[Headlamp](https://headlamp.dev/) is a user-friendly Kubernetes UI focused on extensibility. The Kubescape plugin extends Headlamp with views on Trivy reports.

👉 Get it at: <https://github.com/kubebeam/trivy-headlamp-plugin>
